==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
var WebDropdownHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownHeaderDescriptionMetadata, _super);
    function WebDropdownHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownHeaderDescriptionMetadata.b = function (a) {
        if (WebDropdownHeaderDescriptionMetadata.a == null) {
            WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
        }
        if (a.g(WebDropdownHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownHeader");
    };
    WebDropdownHeaderDescriptionMetadata.d = function (a) {
        WebDropdownHeaderDescriptionMetadata.b(a);
        a.u("WebDropdownHeader", function () { return new WebDropdownHeaderDescription(); });
        a.t("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.$t = markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
}(Base));
export { WebDropdownHeaderDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
var WebDropdownHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownHeaderDescriptionMetadata, _super);
    function WebDropdownHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownHeaderDescriptionMetadata.b = function (a) {
        if (WebDropdownHeaderDescriptionMetadata.a == null) {
            WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
        }
        if (a.j(WebDropdownHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownHeader");
        a.item("__tagNameWC", "String:igc-dropdown-header");
    };
    WebDropdownHeaderDescriptionMetadata.d = function (a) {
        WebDropdownHeaderDescriptionMetadata.b(a);
        a.aa("WebDropdownHeader", function () { return new WebDropdownHeaderDescription(); });
        a.z("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.$t = markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
}(Base));
export { WebDropdownHeaderDescriptionMetadata };
